



# Selection analysis for body size of female and male Atlantic salmon----



setwd("")



# Load packages----
library(readr)
library(ggplot2)
library(dplyr)
library(MASS) 
library(MCMCglmm)
library(gridExtra)
library(psych)
library(Hmisc)
library(sandwich)
library(car)
library(lme4)
library(broom)
library(parallel)




# The below function creates ladder plots for the posterior modes and HPD intervals for parameter estimates from a model----
plot.estimates <- function(x) {
  if (class(x) != "summary.mcmc")
    x <- summary(x)
  n <- dim(x$statistics)[1]
  par(mar=c(2, 7, 4, 1))
  plot(x$statistics[,1], n:1,
       yaxt="n", ylab="",
       xlim=range(x$quantiles)*1.2,
       pch=19,
       main="Posterior means and 95% credible intervals")
  grid()
  axis(2, at=n:1, rownames(x$statistics), las=2)
  arrows(x$quantiles[,1], n:1, x$quantiles[,5], n:1, code=0)
  abline(v=0, lty=2)
}



# Load data and examine its structure
Females <- read_csv("Females.csv")
Males<- read_csv("Males.csv")

str(Females) ; str(Males)
Females$Sex<- as.factor(Females$Sex) ; Males$Sex<- as.factor(Males$Sex)


Females$cohort<- as.numeric(Females$cohort) ; Males$cohort<- as.numeric(Males$cohort)
dim(Females); dim(Males)


# Standardized return length across ALL YEARS----
Females$SRL<- (Females$Length - mean(Females$Length))/sd(Females$Length)




                                      ##########################################################
                                      #                                                        #
                                      #        1.0 What is the nature of selection             #
                                      #       on body size in male and female salmon?----      #
                                      #                                                        #
                                      ##########################################################


# 1.1 For females----
MCMC.Model.1<- MCMCglmm(Number_of_Offspring~1+SRL+I(SRL^2),
                        family = "poisson",
                        data = as.data.frame(Females),
                        verbose = TRUE,
                        nitt=2500000,burnin=500000,thin=1000)

summary(MCMC.Model.1)
plot(MCMC.Model.1$Sol)
plot(MCMC.Model.1$VCV)
diag(autocorr(MCMC.Model.1$Sol)[2,,]) 
autocorr.plot(MCMC.Model.1$Sol)


MCMC.Model.1b<- MCMCglmm(Number_of_Offspring~1+SRL+I(SRL^2),
                                        family = "poisson",
                                        data = as.data.frame(Females),
                                        verbose = TRUE,
                                        nitt=2500000,burnin=500000,thin=1000)

summary(MCMC.Model.1b)
plot(MCMC.Model.1b$Sol)
plot(MCMC.Model.1b$VCV)
diag(autocorr(MCMC.Model.1b$Sol)[2,,]) 
autocorr.plot(MCMC.Model.1b$Sol)


gelman.diag(mcmc.list(MCMC.Model.1$Sol, MCMC.Model.1b$Sol))
plot.estimates(MCMC.Model.1b$Sol)



# 1.2 For males----
# Exclude male grilse

Males2<- Males[! grepl("G", Males$animal), ]
Males2$SRL<- (Males2$Length - mean(Males2$Length))/sd(Males2$Length)


MCMC.Model.3<- MCMCglmm(Number_of_Offspring~1+SRL+I(SRL^2),
                        family = "poisson",
                        data = as.data.frame(Males2),
                        verbose = TRUE,
                        nitt=2500000,burnin=500000,thin=1000)
summary(MCMC.Model.3)
plot(MCMC.Model.3$Sol)
plot(MCMC.Model.3$VCV)
posterior.mode(MCMC.Model.3$Sol[, "SRL"])
HPDinterval(MCMC.Model.3$Sol[, "SRL"])

posterior.mode(MCMC.Model.3$Sol[, "I(SRL^2)"])
HPDinterval(MCMC.Model.3$Sol[, "I(SRL^2)"])

diag(autocorr(MCMC.Model.3$Sol)[2,,]) 
autocorr.plot(MCMC.Model.3$Sol)


MCMC.Model.3b<- MCMCglmm(Number_of_Offspring~1+SRL+I(SRL^2),
                        family = "poisson",
                        data = as.data.frame(Males2),
                        verbose = TRUE,
                        nitt=2500000,burnin=500000,thin=1000)


# Check convergence of fixed factors
gelman.diag(mcmc.list(MCMC.Model.3$Sol, MCMC.Model.3b$Sol))
plot.estimates(MCMC.Model.3$Sol)


# Save  models----
setwd("")

saveRDS(MCMC.Model.1, "Female_Selection.rds")
saveRDS(MCMC.Model.1b, "Female_Selection2.rds")
saveRDS(MCMC.Model.3, "Male_Selection.rds")
saveRDS(MCMC.Model.3b, "Male_Selection2.rds")




# Recalculate linear and nonlinear selection gradients for males and females using the method of Morrissey & Gouldie----
b_males<- MCMC.Model.3$Sol[, "SRL"]
g_males<- MCMC.Model.3$Sol[, "I(SRL^2)"]*2

Beta_males<-b_males/(1-g_males)
posterior.mode(Beta_males)
HPDinterval(Beta_males)

Gamma_males<-(b_males^2+g_males*(1-g_males))/(1-g_males)^2
posterior.mode(Gamma_males)
HPDinterval(Gamma_males)



b_females<- MCMC.Model.1$Sol[, "SRL"]
g_females<- MCMC.Model.1$Sol[, "I(SRL^2)"]*2

Beta_females<-b_females/(1-g_females)
posterior.mode(Beta_females)
HPDinterval(Beta_females)

Gamma_feales<-(b_females^2+g_females*(1-g_females))/(1-g_females)^2
posterior.mode(Gamma_females)
HPDinterval(Gamma_females)




                                
                                ##########################################################
                                #                                                        #
                                #            2.0  Exclude 1989 cohort----                #
                                #                                                        #
                                ##########################################################


Females2<- Females[which(Females$Year_of_Spawning !="1989"),]
Males3<- Males2[which(Males2$Year_of_Spawning !="1989"),]



# Re-run selection analyses----
MCMC.Model.1<- MCMCglmm(Number_of_Offspring~1+SRL+I(SRL^2),
                        family = "poisson",
                        data = as.data.frame(Females2),
                        verbose = TRUE,
                        nitt=2500000,burnin=500000,thin=1000)

summary(MCMC.Model.1)
plot(MCMC.Model.1$Sol)
plot(MCMC.Model.1$VCV)
diag(autocorr(MCMC.Model.1$Sol)[2,,]) 
autocorr.plot(MCMC.Model.1$Sol)

summary(Female.Selection.Model)
posterior.mode(MCMC.Model.1$Sol) ; posterior.mode(Female.Selection.Model$Sol)
HPDinterval(MCMC.Model.1$Sol)    ; HPDinterval(Female.Selection.Model$Sol) 




MCMC.Model.2<- MCMCglmm(Number_of_Offspring~1+SRL+I(SRL^2),
                        family = "poisson",
                        data = as.data.frame(Males3),
                        verbose = TRUE,
                        nitt=2500000,burnin=500000,thin=1000)

summary(MCMC.Model.2)
plot(MCMC.Model.2$Sol)
plot(MCMC.Model.2$VCV)
diag(autocorr(MCMC.Model.2$Sol)[2,,]) 
autocorr.plot(MCMC.Model.2$Sol)

posterior.mode(MCMC.Model.2$Sol) ; posterior.mode(MCMC.Model.3$Sol)
HPDinterval(MCMC.Model.2$Sol)    ; HPDinterval(MCMC.Model.3$Sol) 

