



# Cleaning of pedigree data----


                              ##########################################################
                              #                                                        #
                              #     1.0 Set working directory and load packages----    #
                              #                                                        #
                              ##########################################################

# 1.1 Set working directory and load full pedigree----
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))


  f<- file.choose("Historical_Pedigree_Analysis.csv")
  mydata<-read.csv(f, header = T,sep = ",")
  head(mydata)
  
  
# 1.2 Load packages----
library(pedantics)
library(dplyr) 
library(ggplot2) 
library(gridExtra)
library(MASS)
library(readr)


  
  
                              ###########################################################
                              #                                                         #
                              #                 2.0 Data cleaning----                   #
                              #                                                         #
                              ###########################################################

{
  # 2.1 Extract required columns----
  mydata <- mydata[, c(2, 4,5,6, 7, 12, 13, 3, 8)] 
  head(mydata)
  
  names(mydata)[names(mydata) == 'ID'] <- 'id'
  names(mydata)[names(mydata) == 'Dam'] <- 'dam'
  names(mydata)[names(mydata) == 'Sire'] <- 'sire'
  names(mydata)[names(mydata) == 'Year_of_Spawning'] <- 'cohort'
  
  # 2.1 Drop cohorts greater than 1993 since there is a break in the pedigree----
  length(mydata$id)
  mydata<-mydata[!(mydata$cohort >1993),]
  length(mydata$id)
  
  # 2.2 Fit mean of cohort value for the NAs if we're willing to assume that the NAs occur at random----
  #### N.B. This step is redundant as such NAs have no data associated with them anyway ####
  sum(is.na(mydata$cohort))
  mydata$cohort[is.na(mydata$cohort)] <- round(mean(mydata$cohort, na.rm = TRUE),0)
  sum(is.na(mydata$cohort))
  hist(mydata$cohort)
  
  # 2.3 Recode sex and provenance as integers----
  levels(mydata$Sex)[levels(mydata$Sex)=="M"] <- 0
  levels(mydata$Sex)[levels(mydata$Sex)=="F"] <- 1
  levels(mydata$Provenance)[levels(mydata$Provenance)=="FC"] <- 0
  levels(mydata$Provenance)[levels(mydata$Provenance)=="W"] <- 1
  mydata$Sex <- as.integer(as.character(mydata$Sex))
  head(mydata)

  # 2.4 Remove duplicated rows---- 
  newdata<-mydata[!duplicated(mydata[, 1:3]), ]

  # 2.5 Remove hatchery-spawning FC fish as we are only interested in wild-spawning fish----
  newdata<- newdata[which(newdata$Provenance=="1"),]
  head(newdata)
  tail(newdata)
}

  # 2.6 Remove 1987 cohort as there are only 4 fish, only 3 with phenotypic data----
  newdata<- newdata[-which(newdata$cohort=="1987"),]

  # 2.7 Check structure of phenotypic data----
  str(newdata)
  
{
  newdata$Sex<- as.factor(newdata$Sex)
  newdata$Provenance<- as.factor(newdata$Provenance)
  newdata$cohort<- as.factor(newdata$cohort)
   newdata$Number_of_Offspring<- as.numeric(newdata$Number_of_Offspring)
}
  
 # 2.8 Rename id column as "animal"----
 names(newdata)[1]<- "animal"
  
  
  
  
  
                                    
                                  ##########################################################
                                  #                                                        #
                                  #      3.0 Filter fish without good phenotypic           #
                                  #                 data or LRS data----                   #
                                  #                                                        #
                                  ##########################################################
  
  newdata<-filter(newdata, Length != "NA")
  newdata<-subset(newdata, cohort %in% c("1977","1978","1979","1980","1980","1981","1982",
                                         "1984","1985", "1989")) 
  newdata<-droplevels(newdata)   
  newdata$cohort <- as.factor(newdata$cohort)





###################################### None of the following is used in these analyses ###############################

                              ##########################################################
                              #                                                        #
                              #             4.0 Get the mean LRS and mean              #
                              #            return length for each cohort----           #
                              #                                                        #
                              ##########################################################


# 4.1 Get cohort-specific fitness----
a<- newdata %>%
  group_by(cohort) %>%
  summarize(Wm=mean(Number_of_Offspring, na.rm=TRUE))
newdata2<- merge(newdata, a, by = "cohort")

b<- newdata2 %>%
  group_by(animal) %>%
  summarize(w=Number_of_Offspring/Wm)
newdata3<- merge(newdata2, b, by="animal")



# 4.2 Return length of an individual can be written as the deviation (RLdev) from the cohort-specific mean (RLm)----
c<- newdata3 %>% 
  group_by(cohort) %>%
summarize(RLm=mean(Length, na.rm=TRUE))
newdata4<- merge(newdata3, c, by="cohort")

newdata4$RLdev<- newdata4$Length-newdata4$RLm



# 4.3 Mean and variance standardize RL----
d<- newdata4 %>%
  group_by(cohort) %>%
  summarize(Cohort.sd=sd(Length, na.rm=TRUE))
newdata5<- merge(newdata4, d, by="cohort")

newdata5$RLs<- newdata5$RLdev/newdata5$Cohort.sd



# 4.4 Data checks----
str(newdata5)
with(newdata5, tapply(RLs, cohort, mean, na.rm=T))
with(newdata5, tapply(RLs, cohort, sd, na.rm=T))
with(newdata5, tapply(RLs, cohort, length))
with(newdata5, boxplot(RLs ~ cohort))
with(newdata5, table(cohort, Year_of_Fertilization))

with(newdata5, tapply(w, cohort, mean, na.rm=T))       

with(newdata5, 
     table(Wm, cohort))

newdata5$Year_of_Spawning<- newdata5$cohort

newdata5$cohort<- as.numeric(newdata5$cohort)
newdata5$cohort<- as.factor(newdata5$cohort)
newdata5$cohort<- as.integer(newdata5$cohort)


newdata5$Sex<- as.factor(newdata5$Sex)
sum(is.na(newdata5$Sex))
newdata6<-filter(newdata5, Sex != "NA")
sum(is.na(newdata6$Sex))





                                      ##########################################################
                                      #                                                        #
                                      #         5.0 Split into males and females----           #
                                      #                                                        #
                                      ##########################################################

# 5.1 Subset based on sex----
Males<- subset(newdata6, Sex == "0")
summary(Males$Sex)
Females<- subset(newdata6, Sex == "1")
summary(Females$Sex)




                                      ##########################################################
                                      #                                                        #
                                      #          6.0 Sex-specific fitness measures----         #
                                      #                                                        #
                                      ##########################################################         
# 6.1 For males----
Male.CSF<- Males %>%
  group_by(cohort) %>%
  summarize(Male.Wm=mean(Number_of_Offspring, na.rm=TRUE))
Males<- merge(Males, Male.CSF, by = "cohort")

wMale<- Males %>%
  group_by(animal) %>%
  summarize(Male.w=Number_of_Offspring/Male.Wm)
Males<- merge(Males, wMale, by="animal")

# 6.2 For females----
Female.CSF<- Females %>%
  group_by(cohort) %>%
  summarize(Female.Wm=mean(Number_of_Offspring, na.rm = TRUE))
Females<- merge(Females, Female.CSF, by = "cohort")

wFemale<- Females%>%
  group_by(animal) %>%
  summarize(Female.w=Number_of_Offspring/Female.Wm)
Females<- merge(Females, wFemale, by="animal")





                                ##########################################################
                                #                                                        #
                                #         7.0 Sex-specific return length measures----    #
                                #                                                        #
                                ##########################################################


# 7.1 Male RL----
Male.RLm<- Males %>% 
  group_by(cohort) %>%
  summarize(Male.RLm=mean(Length, na.rm=TRUE))
Males<- merge(Males, Male.RLm, by="cohort")

Males$Male.RLdev<- Males$Length-Males$Male.RLm

# 7.2 Mean and variance standardize RL----
d<- Males %>%
  group_by(cohort) %>%
  summarize(Male.Cohort.sd=sd(Length, na.rm=TRUE))
Males<- merge(Males, d, by="cohort")

Males$Male.RLs<- Males$Male.RLdev/Males$Male.Cohort.sd

# 7.3 Female RL----
Female.RLm<- Females %>% 
  group_by(cohort) %>%
  summarize(Female.RLm=mean(Length, na.rm=TRUE))
Females<- merge(Females, Female.RLm, by="cohort")

Females$Female.RLdev<- Females$Length-Females$Female.RLm

# 7.4 Mean and variance standardize RL----
d<- Females %>%
  group_by(cohort) %>%
  summarize(Female.Cohort.sd=sd(Length, na.rm=TRUE))
Females<- merge(Females, d, by="cohort")

Females$Female.RLs<- Females$Female.RLdev/Females$Female.Cohort.sd



setwd("")

write.csv(Males, file = "Males.csv")
write.csv(Females, file = "Females.csv")
write.csv(newdata6, file = "Pedigree_Final.csv")

